
import sys
if sys.version_info >= (3, 8):
    from typing import Protocol
else:
    from typing_extensions import Protocol

import java.lang
import jpype
import jneqsim.neqsim.physicalproperties.mixingrule
import jneqsim.neqsim.physicalproperties.physicalpropertymethods.methodinterface
import jneqsim.neqsim.physicalproperties.physicalpropertysystem.commonphasephysicalproperties
import jneqsim.neqsim.physicalproperties.physicalpropertysystem.gasphysicalproperties
import jneqsim.neqsim.physicalproperties.physicalpropertysystem.liquidphysicalproperties
import jneqsim.neqsim.physicalproperties.physicalpropertysystem.solidphysicalproperties
import jneqsim.neqsim.thermo
import jneqsim.neqsim.thermo.phase
import typing



class PhysicalPropertiesInterface(java.lang.Cloneable):
    def calcDensity(self) -> float: ...
    def calcEffectiveDiffusionCoefficients(self) -> None: ...
    def clone(self) -> 'PhysicalPropertiesInterface': ...
    def getConductivity(self) -> float: ...
    def getConductivityModel(self) -> jneqsim.neqsim.physicalproperties.physicalpropertymethods.methodinterface.ConductivityInterface: ...
    def getDensity(self) -> float: ...
    @typing.overload
    def getDiffusionCoefficient(self, int: int, int2: int) -> float: ...
    @typing.overload
    def getDiffusionCoefficient(self, string: typing.Union[java.lang.String, str], string2: typing.Union[java.lang.String, str]) -> float: ...
    @typing.overload
    def getEffectiveDiffusionCoefficient(self, int: int) -> float: ...
    @typing.overload
    def getEffectiveDiffusionCoefficient(self, string: typing.Union[java.lang.String, str]) -> float: ...
    def getEffectiveSchmidtNumber(self, int: int) -> float: ...
    def getFickDiffusionCoefficient(self, int: int, int2: int) -> float: ...
    def getKinematicViscosity(self) -> float: ...
    def getMixingRule(self) -> jneqsim.neqsim.physicalproperties.mixingrule.PhysicalPropertyMixingRuleInterface: ...
    def getPhase(self) -> jneqsim.neqsim.thermo.phase.PhaseInterface: ...
    def getPureComponentViscosity(self, int: int) -> float: ...
    def getViscosity(self) -> float: ...
    def getViscosityModel(self) -> jneqsim.neqsim.physicalproperties.physicalpropertymethods.methodinterface.ViscosityInterface: ...
    def getViscosityOfWaxyOil(self, double: float, double2: float) -> float: ...
    @typing.overload
    def init(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface) -> None: ...
    @typing.overload
    def init(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface, string: typing.Union[java.lang.String, str]) -> None: ...
    def setBinaryDiffusionCoefficientMethod(self, int: int) -> None: ...
    def setConductivityModel(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setDensityModel(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setMixingRule(self, physicalPropertyMixingRuleInterface: jneqsim.neqsim.physicalproperties.mixingrule.PhysicalPropertyMixingRuleInterface) -> None: ...
    def setMixingRuleNull(self) -> None: ...
    def setMulticomponentDiffusionMethod(self, int: int) -> None: ...
    def setPhase(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface) -> None: ...
    def setViscosityModel(self, string: typing.Union[java.lang.String, str]) -> None: ...

class PhysicalProperties(PhysicalPropertiesInterface, jneqsim.neqsim.thermo.ThermodynamicConstantsInterface):
    phase: jneqsim.neqsim.thermo.phase.PhaseInterface = ...
    conductivityCalc: jneqsim.neqsim.physicalproperties.physicalpropertymethods.methodinterface.ConductivityInterface = ...
    viscosityCalc: jneqsim.neqsim.physicalproperties.physicalpropertymethods.methodinterface.ViscosityInterface = ...
    diffusivityCalc: jneqsim.neqsim.physicalproperties.physicalpropertymethods.methodinterface.DiffusivityInterface = ...
    densityCalc: jneqsim.neqsim.physicalproperties.physicalpropertymethods.methodinterface.DensityInterface = ...
    kinematicViscosity: float = ...
    density: float = ...
    viscosity: float = ...
    conductivity: float = ...
    @typing.overload
    def __init__(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface): ...
    @typing.overload
    def __init__(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface, int: int, int2: int): ...
    def calcDensity(self) -> float: ...
    def calcEffectiveDiffusionCoefficients(self) -> None: ...
    def calcKinematicViscosity(self) -> float: ...
    def clone(self) -> 'PhysicalProperties': ...
    def getConductivity(self) -> float: ...
    def getConductivityModel(self) -> jneqsim.neqsim.physicalproperties.physicalpropertymethods.methodinterface.ConductivityInterface: ...
    def getDensity(self) -> float: ...
    @typing.overload
    def getDiffusionCoefficient(self, int: int, int2: int) -> float: ...
    @typing.overload
    def getDiffusionCoefficient(self, string: typing.Union[java.lang.String, str], string2: typing.Union[java.lang.String, str]) -> float: ...
    @typing.overload
    def getEffectiveDiffusionCoefficient(self, int: int) -> float: ...
    @typing.overload
    def getEffectiveDiffusionCoefficient(self, string: typing.Union[java.lang.String, str]) -> float: ...
    def getEffectiveSchmidtNumber(self, int: int) -> float: ...
    def getFickDiffusionCoefficient(self, int: int, int2: int) -> float: ...
    def getKinematicViscosity(self) -> float: ...
    def getMixingRule(self) -> jneqsim.neqsim.physicalproperties.mixingrule.PhysicalPropertyMixingRuleInterface: ...
    def getPhase(self) -> jneqsim.neqsim.thermo.phase.PhaseInterface: ...
    def getPureComponentViscosity(self, int: int) -> float: ...
    def getViscosity(self) -> float: ...
    def getViscosityModel(self) -> jneqsim.neqsim.physicalproperties.physicalpropertymethods.methodinterface.ViscosityInterface: ...
    def getViscosityOfWaxyOil(self, double: float, double2: float) -> float: ...
    def getWaxViscosityParameter(self) -> typing.MutableSequence[float]: ...
    @typing.overload
    def init(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface) -> None: ...
    @typing.overload
    def init(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface, string: typing.Union[java.lang.String, str]) -> None: ...
    def setBinaryDiffusionCoefficientMethod(self, int: int) -> None: ...
    def setConductivityModel(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setDensityModel(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setDiffusionCoefficientModel(self, string: typing.Union[java.lang.String, str]) -> None: ...
    def setMixingRule(self, physicalPropertyMixingRuleInterface: jneqsim.neqsim.physicalproperties.mixingrule.PhysicalPropertyMixingRuleInterface) -> None: ...
    def setMixingRuleNull(self) -> None: ...
    def setMulticomponentDiffusionMethod(self, int: int) -> None: ...
    def setPhase(self, phaseInterface: jneqsim.neqsim.thermo.phase.PhaseInterface) -> None: ...
    def setPhases(self) -> None: ...
    def setViscosityModel(self, string: typing.Union[java.lang.String, str]) -> None: ...
    @typing.overload
    def setWaxViscosityParameter(self, doubleArray: typing.Union[typing.List[float], jpype.JArray]) -> None: ...
    @typing.overload
    def setWaxViscosityParameter(self, int: int, double: float) -> None: ...


class __module_protocol__(Protocol):
    # A module protocol which reflects the result of ``jp.JPackage("jneqsim.neqsim.physicalproperties.physicalpropertysystem")``.

    PhysicalProperties: typing.Type[PhysicalProperties]
    PhysicalPropertiesInterface: typing.Type[PhysicalPropertiesInterface]
    commonphasephysicalproperties: jneqsim.neqsim.physicalproperties.physicalpropertysystem.commonphasephysicalproperties.__module_protocol__
    gasphysicalproperties: jneqsim.neqsim.physicalproperties.physicalpropertysystem.gasphysicalproperties.__module_protocol__
    liquidphysicalproperties: jneqsim.neqsim.physicalproperties.physicalpropertysystem.liquidphysicalproperties.__module_protocol__
    solidphysicalproperties: jneqsim.neqsim.physicalproperties.physicalpropertysystem.solidphysicalproperties.__module_protocol__
